Package: EMCluster
Version: 0.2-17
Date: 2024-12-24
Title: EM Algorithm for Model-Based Clustering of Finite Mixture
        Gaussian Distribution
Authors@R: c(person("Wei-Chen", "Chen", role = c("aut", "cre"), email =
        "wccsnow@gmail.com"),
        person("Ranjan", "Maitra", role = "aut", email = "maitra@iastate.edu"),
        person("Volodymyr", "Melnykov", role = "ctb"),
        person("Dan", "Nettleton", role = "ctb"),
        person("David", "Faden", role = "ctb"),
        person("Rouben", "Rostamian", role = "ctb"),
        person("R Core team", role = "ctb", comment = "some functions are
                modified from the R source code"))
Depends: R (>= 4.0.0), MASS, Matrix, methods
Enhances: RColorBrewer
LazyLoad: yes
LazyData: yes
Description: EM algorithms and several efficient
        initialization methods for model-based clustering of finite
        mixture Gaussian distribution with unstructured dispersion
        in both of unsupervised and semi-supervised learning.
License: Mozilla Public License 2.0
BugReports: https://github.com/snoweye/EMCluster/issues
URL: https://github.com/snoweye/EMCluster
NeedsCompilation: yes
Maintainer: Wei-Chen Chen <wccsnow@gmail.com>
Packaged: 2024-12-24 18:52:12 UTC; snoweye
Author: Wei-Chen Chen [aut, cre],
  Ranjan Maitra [aut],
  Volodymyr Melnykov [ctb],
  Dan Nettleton [ctb],
  David Faden [ctb],
  Rouben Rostamian [ctb],
  R Core team [ctb] (some functions are modified from the R source code)
Repository: CRAN
Date/Publication: 2025-01-09 05:00:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-27 09:04:03 UTC; unix
Archs: EMCluster.so.dSYM
