# EMCluster

* **License:** [![License](https://img.shields.io/badge/license-GPL%20v2-orange.svg?style=flat)](https://www.gnu.org/licenses/gpl-2.0.en.html)
* **Download:** [![Download](https://cranlogs.r-pkg.org/badges/EMCluster)](https://cran.r-project.org/package=EMCluster)
* **Author:** Wei-Chen Chen and Ranjan Maitra 


EMCluster is an R package providing EM algorithms and several efficient
initialization methods for model-based clustering of finite
mixture Gaussian distribution with unstructured dispersion
in both of unsupervised and semi-supervised learning.



## Installation

EMCluster requires
* R version 3.0.0 or higher.
* R package MASS, Matrix.

The package can be installed from the CRAN via the usual
`install.packages("EMCluster")`, or via the devtools package:

```r
library(devtools)
install_github("snoweye/EMCluster")
```

